task VarScan {

  String sample
  File normal_bam
  File normal_bam_index
  File tumor_bam
  File tumor_bam_index

  File ref_dir
  String fasta
  String docker
  String cluster_config
  String disk_size

  command <<<
    # somatic
    samtools mpileup -f ${ref_dir}/${fasta} -B ${normal_bam} ${tumor_bam} | java -Xmx64g -jar /opt/VarScan.v2.4.3.jar somatic --mpileup 1 --min-coverage 3 --min-coverage-normal 3 --min-coverage-tumor 3 --min-var-freq 0.08 --p-value 0.10 --somatic-p-value 0.05 --output-vcf 1 --output-snp ${sample}.VarScan.SNP --output-indel ${sample}.VarScan.INDEL --strand-filter 1

    # processSomatic
    java -Xmx64g -jar /opt/VarScan.v2.4.3.jar processSomatic ${sample}.VarScan.SNP.vcf
    java -Xmx64g -jar /opt/VarScan.v2.4.3.jar processSomatic ${sample}.VarScan.INDEL.vcf

    # somaticFilter
    java -Xmx64g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${sample}.VarScan.SNP.Somatic.hc.vcf --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --indel-file ${sample}.VarScan.INDEL.vcf --output-file ${sample}.VarScan.SNP.Somatic.filter.vcf
    java -Xmx64g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${sample}.VarScan.SNP.Germline.hc.vcf --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --indel-file ${sample}.VarScan.INDEL.vcf --output-file ${sample}.VarScan.SNP.Germline.filter.vcf
    java -Xmx64g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${sample}.VarScan.SNP.LOH.hc.vcf --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --indel-file ${sample}.VarScan.INDEL.vcf --output-file ${sample}.VarScan.SNP.LOH.filter.vcf
    java -Xmx64g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${sample}.VarScan.INDEL.Somatic.hc.vcf --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --output-file ${sample}.VarScan.INDEL.Somatic.filter.vcf
    java -Xmx64g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${sample}.VarScan.INDEL.Germline.hc.vcf --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --output-file ${sample}.VarScan.INDEL.Germline.filter.vcf
    java -Xmx64g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${sample}.VarScan.INDEL.LOH.hc.vcf --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --output-file ${sample}.VarScan.INDEL.LOH.filter.vcf

    # Merge SNP and INDEL
    awk '{if ($1!~/^#/) print}' ${sample}.VarScan.SNP.Somatic.filter.vcf | cat ${sample}.VarScan.INDEL.Somatic.filter.vcf - > ${sample}.VarScan.Somatic.vcf
    awk '{if ($1!~/^#/) print}' ${sample}.VarScan.SNP.Germline.filter.vcf | cat ${sample}.VarScan.INDEL.Germline.filter.vcf - > ${sample}.VarScan.Germline.vcf
    awk '{if ($1!~/^#/) print}' ${sample}.VarScan.SNP.LOH.filter.vcf | cat ${sample}.VarScan.INDEL.LOH.filter.vcf - > ${sample}.VarScan.LOH.vcf
  >>>
  
  runtime {
    docker: docker
    cluster: cluster_config
    systemDisk: "cloud_ssd 40"
    dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
  }
  
  output {
    File varscan_snp = "${sample}.VarScan.SNP.vcf"
    File varscan_indel = "${sample}.VarScan.INDEL.vcf"
		File varscan_somatic = "${sample}.VarScan.Somatic.vcf"
    File varscan_germline = "${sample}.VarScan.Germline.vcf"
		File varscan_loh = "${sample}.VarScan.LOH.vcf"
  }
}